@@ -15,6 +15,7 @@ from explorer.views.auth import PermissionRequiredMixin
 from explorer.views.mixins import ExplorerContextMixin
 from explorer.views.utils import query_viewmodel
 
+from django.utils.translation import gettext_lazy as _ 
 
 class PlayQueryView(PermissionRequiredMixin, ExplorerContextMixin, View):
 
@@ -74,7 +75,7 @@ class PlayQueryView(PermissionRequiredMixin, ExplorerContextMixin, View):
         return self.render_template(
             f'explorer/{template}.html',
             query_viewmodel(
-                request.user,
+                request,
                 query,
                 title="Playground",
                 run_query=run_query,
@@ -95,7 +96,7 @@ class QueryView(PermissionRequiredMixin, ExplorerContextMixin, View):
         show = url_get_show(request)
         rows = url_get_rows(request)
         vm = query_viewmodel(
-            request.user,
+            request,
             query,
             form=form,
             run_query=show,
@@ -116,12 +117,12 @@ class QueryView(PermissionRequiredMixin, ExplorerContextMixin, View):
         query, form = QueryView.get_instance_and_form(request, query_id)
         success = form.is_valid() and form.save()
         vm = query_viewmodel(
-            request.user,
+            request,
             query,
             form=form,
             run_query=show,
             rows=url_get_rows(request),
-            message="Query saved." if success else None
+            message=_("Query saved.") if success else None
         )
         return self.render_template('explorer/query.html', vm)
 
